==> pipewire-docs-0.3.10-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Introduction", "index.html#sec_intro", null ],
    [ "Error reporting", "index.html#sec_errors", null ],
    [ "Logging", "index.html#sec_logging", null ],
    [ "Core API", "page_context_api.html", "page_context_api" ],
    [ "Control", "page_control.html", [
      [ "Overview", "page_control.html#page_control_overview", null ]
    ] ],
    [ "pw_core", "page_iface_pw_core.html", [
      [ "Description", "page_iface_pw_core.html#page_iface_pw_core_desc", null ],
      [ "API", "page_iface_pw_core.html#page_iface_pw_core", null ]
    ] ],
    [ "Registry", "page_registry.html", [
      [ "Overview", "page_registry.html#page_registry_overview", null ]
    ] ],
    [ "Proxy", "page_proxy.html", [
      [ "Overview", "page_proxy.html#sec_page_proxy_overview", null ],
      [ "Core proxy", "page_proxy.html#sec_page_proxy_core", null ],
      [ "Create", "page_proxy.html#sec_page_proxy_create", null ],
      [ "Bind", "page_proxy.html#sec_page_proxy_bind", null ],
      [ "Methods", "page_proxy.html#sec_page_proxy_methods", null ],
      [ "Events", "page_proxy.html#sec_page_proxy_events", null ],
      [ "Destroy", "page_proxy.html#sec_page_proxy_destroy", null ]
    ] ],
    [ "Media Streams", "page_streams.html", [
      [ "Overview", "page_streams.html#sec_overview", null ],
      [ "Create", "page_streams.html#sec_create", null ],
      [ "Connect", "page_streams.html#sec_connect", [
        [ "Stream target", "page_streams.html#ssec_stream_target", null ],
        [ "Stream formats", "page_streams.html#ssec_stream_formats", null ]
      ] ],
      [ "Format negotiation", "page_streams.html#sec_format", null ],
      [ "Buffer negotiation", "page_streams.html#sec_buffers", null ],
      [ "Streaming", "page_streams.html#sec_streaming", [
        [ "Consume data", "page_streams.html#ssec_consume", null ],
        [ "Produce data", "page_streams.html#ssec_produce", null ]
      ] ],
      [ "Disconnect", "page_streams.html#sec_stream_disconnect", null ]
    ] ],
    [ "Threaded Loop", "page_thread_loop.html", [
      [ "Overview", "page_thread_loop.html#sec_thread_loop_overview", null ],
      [ "Creation", "page_thread_loop.html#sec_thread_loop_create", null ],
      [ "Destruction", "page_thread_loop.html#sec_thread_loop_destruction", null ],
      [ "Locking", "page_thread_loop.html#sec_thread_loop_locking", null ],
      [ "Events and Callbacks", "page_thread_loop.html#sec_thread_loop_events", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
"global_8h.html#a3c30e6a36a12ab02e97c7a0014d578d0",
"impl-node_8c.html#a0c09f345941b97bd6bc796ee014214f0",
"link_8h.html#a481b4d0b9cd49478fd13dc8934478840",
"pages.html",
"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b",
"structpw__device__methods.html",
"structpw__protocol__client.html#a020b1da93f4f58c485ff64da4a5ac655"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-0.3.19-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Introduction", "index.html#sec_intro", null ],
    [ "Error reporting", "index.html#sec_errors", null ],
    [ "Logging", "index.html#sec_logging", null ],
    [ "Core API", "page_context_api.html", "page_context_api" ],
    [ "Control", "page_control.html", [
      [ "Overview", "page_control.html#page_control_overview", null ]
    ] ],
    [ "pw_core", "page_iface_pw_core.html", [
      [ "Description", "page_iface_pw_core.html#page_iface_pw_core_desc", null ],
      [ "API", "page_iface_pw_core.html#page_iface_pw_core", null ]
    ] ],
    [ "Registry", "page_registry.html", [
      [ "Overview", "page_registry.html#page_registry_overview", null ]
    ] ],
    [ "Proxy", "page_proxy.html", [
      [ "Overview", "page_proxy.html#sec_page_proxy_overview", null ],
      [ "Core proxy", "page_proxy.html#sec_page_proxy_core", null ],
      [ "Create", "page_proxy.html#sec_page_proxy_create", null ],
      [ "Bind", "page_proxy.html#sec_page_proxy_bind", null ],
      [ "Methods", "page_proxy.html#sec_page_proxy_methods", null ],
      [ "Events", "page_proxy.html#sec_page_proxy_events", null ],
      [ "Destroy", "page_proxy.html#sec_page_proxy_destroy", null ]
    ] ],
    [ "Media Streams", "page_streams.html", [
      [ "Overview", "page_streams.html#sec_overview", null ],
      [ "Create", "page_streams.html#sec_create", null ],
      [ "Connect", "page_streams.html#sec_connect", [
        [ "Stream target", "page_streams.html#ssec_stream_target", null ],
        [ "Stream formats", "page_streams.html#ssec_stream_formats", null ]
      ] ],
      [ "Format negotiation", "page_streams.html#sec_format", null ],
      [ "Buffer negotiation", "page_streams.html#sec_buffers", null ],
      [ "Streaming", "page_streams.html#sec_streaming", [
        [ "Consume data", "page_streams.html#ssec_consume", null ],
        [ "Produce data", "page_streams.html#ssec_produce", null ]
      ] ],
      [ "Disconnect", "page_streams.html#sec_stream_disconnect", null ]
    ] ],
    [ "Threaded Loop", "page_thread_loop.html", [
      [ "Overview", "page_thread_loop.html#sec_thread_loop_overview", null ],
      [ "Creation", "page_thread_loop.html#sec_thread_loop_create", null ],
      [ "Destruction", "page_thread_loop.html#sec_thread_loop_destruction", null ],
      [ "Locking", "page_thread_loop.html#sec_thread_loop_locking", null ],
      [ "Events and Callbacks", "page_thread_loop.html#sec_thread_loop_events", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
"global_8h.html#a3c30e6a36a12ab02e97c7a0014d578d0",
"impl-node_8c.html#a15f24a773042bebdd3f5341791be7e13",
"keys_8h.html#aff405f056c4afbeb87df6f663178b993",
"page_streams.html#ssec_stream_formats",
"stream_8c.html#ac9d87c5da34f1357637309ffdd1185cb",
"structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa",
"structpw__properties.html#a15a72cca30ebffc472fb46cfa8b22c43"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
